@@ -168,10 +168,10 @@ inline void init_local_particle_force(Particle *part) {
   }
 
 #ifdef EXTERNAL_FORCES
-  if(part->l.ext_flag & PARTICLE_EXT_FORCE) {
-    part->f.f[0] += part->l.ext_force[0];
-    part->f.f[1] += part->l.ext_force[1];
-    part->f.f[2] += part->l.ext_force[2];
+  if(part->p.ext_flag & PARTICLE_EXT_FORCE) {
+    part->f.f[0] += part->p.ext_force[0];
+    part->f.f[1] += part->p.ext_force[1];
+    part->f.f[2] += part->p.ext_force[2];
   }
 #endif
 
@@ -184,10 +184,10 @@ inline void init_local_particle_force(Particle *part) {
     part->f.torque[2] = 0;
 
     #ifdef EXTERNAL_FORCES
-      if(part->l.ext_flag & PARTICLE_EXT_TORQUE) {
-        part->f.torque[0] += part->l.ext_torque[0];
-        part->f.torque[1] += part->l.ext_torque[1];
-        part->f.torque[2] += part->l.ext_torque[2];
+      if(part->p.ext_flag & PARTICLE_EXT_TORQUE) {
+        part->f.torque[0] += part->p.ext_torque[0];
+        part->f.torque[1] += part->p.ext_torque[1];
+        part->f.torque[2] += part->p.ext_torque[2];
       }
     #endif
 
@@ -272,6 +272,8 @@ inline void force_calc()
 #endif
   init_forces();
 
+  calc_long_range_forces();
+
   switch (cell_structure.type) {
   case CELL_STRUCTURE_LAYERED:
     layered_calculate_ia();
@@ -311,8 +313,6 @@ inline void force_calc()
     }
 #endif
 
-  calc_long_range_forces();
-
 #ifdef LB
   if (lattice_switch & LATTICE_LB) calc_particle_lattice_ia() ;
 #endif
@@ -624,7 +624,8 @@ inline void add_bonded_force(Particle *p1)
   char *errtxt;
   Particle *p2, *p3 = NULL, *p4 = NULL;
   Bonded_ia_parameters *iaparams;
-  int i, j, type_num, type, n_partners, bond_broken;
+  int i, j, type_num, n_partners, bond_broken;
+  BondedInteraction type;
 
   i = 0;
   while(i<p1->bl.n) {
